# ContainerConfig

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**version** | **str** |  | [optional] 
**strategy** | **str** |  | [optional] 
**segmentation_strategy** | **str** |  | [optional] 
**shap_explanation_count** | **float** |  | [optional] 
**attach_shapley_explanation** | **bool** |  | [optional] 
**override_targeting_model_bin_count** | **float** |  | [optional] 
**override_targeting_method** | **str** |  | [optional] 
**save_predictions_to_snowflake** | **bool** |  | [optional] 
**snowflake_model_key** | **str** |  | [optional] 
**seed** | **float** |  | [optional] 
**hyperparameters** | **object** |  | [optional] 
**hyperparameter_default_behavior** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

